==> file_location_listing-v0.2.2.tar.bz2: file_location_listing-v0.2.2/server/server.py <==
#!/usr/bin/env python3
#
# 
# A quickly hacked together "proof of search"
#
#
'''
Copyright (c) 2023 B Tasker

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

    Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
'''

from flask import Flask, request, send_from_directory, send_file
import os
import sys
import time


sys.path.append(os.path.join(os.path.dirname(__file__), '../lib'))

import config
import storage
import dosearch

app = Flask(__name__)

LAST_INDEX_CHECK = time.time()

@app.route("/search/", methods=['POST'])
def search():
    
    global LAST_INDEX_CHECK
    
    # Check that the index is up to date
    # and refresh if not
    if time.time() - LAST_INDEX_CHECK > 300:
        LAST_INDEX_CHECK = time.time()
        # Check the index
        if not storage.getIsIndexFresh():
            storage.loadIndex()
    
    j = request.get_json(force=True)
    
    srchterm = j['term'].lower()
    
    
    search_type = "ALL"
    if "type" in j:
        search_type = j['type']
    
    limit = False
    if "limit" in j:
        limit = int(j["limit"])
    
    return dosearch.search(srchterm, search_type, limit)


@app.route("/thumbs/<path:path>", methods=["GET"])
def thumbnail(path):
    return send_from_directory(f"{DB_PATH}/thumbs/", path)


@app.route("/static/<path:path>", methods=["GET"])
def staticassets(path):
    return send_from_directory(f"static/", path)

@app.route("/", methods=["GET"])
def index():
    return send_file(f"index.html")
    

if __name__ == "__main__":
    DB_PATH = config.getDBPath()
    dosearch.init(DB_PATH)
    app.run(debug=True, host="0.0.0.0", port=5000)

==> file_location_listing-v0.2.4.tar.bz2: file_location_listing-v0.2.4/server/server.py <==
#!/usr/bin/env python3
#
# 
# A quickly hacked together "proof of search"
#
#
'''
Copyright (c) 2023 B Tasker

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

    Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
'''

from flask import Flask, request, send_from_directory, send_file
import os
import sys
import time


sys.path.append(os.path.join(os.path.dirname(__file__), '../lib'))

import config
import storage
import dosearch

app = Flask(__name__)

LAST_INDEX_CHECK = time.time()

@app.route("/search/", methods=['POST'])
def search():
    
    global LAST_INDEX_CHECK
    
    # Check that the index is up to date
    # and refresh if not
    if time.time() - LAST_INDEX_CHECK > 300:
        LAST_INDEX_CHECK = time.time()
        # Check the index
        if not storage.getIsIndexFresh():
            storage.loadIndex()
    
    j = request.get_json(force=True)
    
    srchterm = j['term'].lower()
    
    
    search_type = "ALL"
    if "type" in j:
        search_type = j['type']
    
    limit = False
    if "limit" in j:
        limit = int(j["limit"])
    
    return {
        "results" : dosearch.search(srchterm, search_type, limit)
    }
    


@app.route("/thumbs/<path:path>", methods=["GET"])
def thumbnail(path):
    return send_from_directory(f"{DB_PATH}/thumbs/", path)


@app.route("/static/<path:path>", methods=["GET"])
def staticassets(path):
    return send_from_directory(f"static/", path)

@app.route("/", methods=["GET"])
def index():
    return send_file(f"index.html")
    

if __name__ == "__main__":
    DB_PATH = config.getDBPath()
    dosearch.init(DB_PATH)
    app.run(debug=True, host="0.0.0.0", port=5000)
